United States Court of Appeals, Eleventh Circuit
Description: The United States Court of Appeals for the Eleventh Circuit
Keywords: court of appeals, U.S. Courts, opinions, Eleventh Circuit, 11th Circuit, United States Court of Appeals

Unpublished Opinions Listed by Case Name (Newest First)

Listing 1 - 20 of 18960 results.

Page: 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 >>

Case Name | Appeal Case # | District Court Docket # | Type | Date of Issuance
--- | --- | --- | --- | ---
Harold A. Taylor v. Teakdecking Systems, Inc. | 13-12057 | 8:11-cv-02709SCB-TGW | NEW | 07-02-2014
USA v. Benjamin Caine | 13-15379 | 3:13-cr-00011-MMH-MCR-1 | NEW | 07-02-2014
USA v. Darrell Len Hamilton | 13-15070 | 8:13-cr-00230-SDM-AEP-1 | NEW | 07-02-2014
USA v. Jeffery Barnes | 14-10027 | 4:13-cr-00133-BAE-GRS-1 | NEW | 07-02-2014
USA v. John W. Rudolph | 13-14916 | 3:13-cr-00052-LC-1 | NEW | 07-02-2014
USA v. Willie Bentley | 13-14362 | 0:11-cr-60012-JIC-2 | NEW | 07-02-2014
Biljana Pivac v. Component Services & Logistics, Inc. | 13-11699 | 8:12-cv-00066-EAK-AEP | NEW | 07-01-2014
Estate of Michelle Evette McCall, et al. v. USA | 09-16375 | 3:07-cv-00508-MCR-EMT | NEW | 07-01-2014
Matthew Paul Morris v. Paul C. May, et al | 13-13996 | 2:13-cv-14017-DLG | NEW | 07-01-2014
Narconon Spring Hill, Inc. v. Hernando County, Florida | 13-12014 | 8:11-cv-01368-JDW-TGW | NEW | 07-01-2014
Tammy Wells v. General Dynamics Information Technology, Inc., et al. | 13-12962 | 5:12-cv-00018-MTT | NEW | 07-01-2014
USA v. Pikerson Mentor | 13-10611 | 1:11-cr-20351-DLG-1 | NEW | 07-01-2014
Amber Hatcher, et al v. hannon Fusco | 13-11989 | 2:13-cv-00138-UA-DNF | NEW | 06-30-2014
Charles Jackson Friedlander v. USA | 13-10439 | 8:12-cv-00723-JDW-TGW | NEW | 06-30-2014
Charlton Paul Green v. State of Georgia, et al | 14-10098 | 1:11-cv-04544-AT | NEW | 06-30-2014
Elias Gaston Martinic Reyes, et al. v. U.S. Attorney General | 13-13702 | A087-579-421 | NEW | 06-30-2014
Eternal Word Television Network, Inc. v. Secretary of the U.S. Department of Health and Human Services, et al | 14-12696 | 1:13-cv-00521-CG-C | ORD | 06-30-2014
Eternal Word Television Network, Inc. v. Secretary, U.S. Department of Health and Human Services, et al. | 14-12696 | 1:13-cv-00521-CG-C | ORD | 06-30-2014
Richard Lee Mullinax v. Frank McKeithen, et al. | 13-13631 | 5:12-cv-00341-RS-CJK | NEW | 06-30-2014
USA v. Marshall H. Foskey | 13-14327 | 5:10-cr-00024-MTT-CHW-1 | NEW | 06-30-2014

Page: 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 >>